# Changelog

All notable changes to the AI Prishtina Milvus Client will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [1.0.2] - 2025-01-05

### Added
- Download statistics badges in README.md
- PyPI version badge for real-time version display
- Monthly and total download counters
- Support/donation section with coffee link

### Changed
- Enhanced README.md with better badge layout
- Improved project visibility with download metrics

## [1.0.1] - 2025-01-05

### Added
- Comprehensive dual-license structure (AGPL-3.0 + Commercial)
- License headers to all Python source files
- LICENSE-NOTICE.md for distribution reference
- DUAL_LICENSE_IMPLEMENTATION.md documentation
- Commercial licensing contact information

### Changed
- Updated LICENSE from MIT to dual-license (AGPL-3.0 OR Commercial)
- Updated pyproject.toml license metadata
- Updated README.md with dual-license information
- Updated docs/README.md with licensing details
- Updated QUICK_REFERENCE.md with license notice

### Fixed
- Package metadata now correctly reflects dual-license structure
- All source files now have proper copyright headers
- Documentation consistency across all files

## [1.0.0] - 2025-01-05

### Added
- Initial release of AI Prishtina Milvus Client
- Comprehensive async/sync Milvus client implementation
- Advanced search capabilities with metadata filtering
- Batch processing with progress tracking
- Multi-cloud storage integration (AWS S3, GCP, Azure)
- Real-time streaming with Kafka integration
- Enterprise security features with encryption
- Comprehensive monitoring and metrics collection
- Error recovery and retry mechanisms
- Data validation and transformation
- Performance optimization features
- Development tools and debugging utilities
- Distributed processing capabilities
- Integration testing infrastructure with Docker
- Comprehensive documentation and examples
- Professional README with extensive examples
- Quick reference guide

### Features
- **Core Functionality**:
  - Async/await support for high-performance operations
  - Full CRUD operations for vectors and collections
  - Advanced indexing (IVF, HNSW, ANNOY)
  - Metadata support with complex filtering

- **Enterprise Features**:
  - Role-based access control and authentication
  - Data encryption and security management
  - Comprehensive monitoring with Prometheus integration
  - Backup and recovery procedures
  - Performance optimization and caching

- **Integration Capabilities**:
  - Multi-cloud storage (S3, GCS, Azure Blob)
  - Real-time streaming with Kafka
  - API integrations (OpenAI, HuggingFace, Cohere)
  - Redis caching and session management

- **Developer Experience**:
  - Comprehensive test suite (unit + integration)
  - Docker-based development environment
  - Extensive documentation and examples
  - Type hints and runtime validation
  - Professional error handling

### Technical Specifications
- Python 3.9+ support
- Milvus 2.3.0+ compatibility
- Async/await throughout
- Type-safe with Pydantic validation
- Comprehensive test coverage
- Production-ready architecture

---

## Release Notes

### Version 1.0.1
This release focuses on implementing a professional dual-license structure that allows:
- **Free use** for open-source projects under AGPL-3.0
- **Commercial licensing** for proprietary applications

This change ensures sustainable development while maintaining open-source accessibility.

### Version 1.0.0
The initial release provides a comprehensive, production-ready Python client for Milvus vector database with enterprise-grade features including security, monitoring, streaming, and multi-cloud integration.

---

## Upgrade Guide

### From 1.0.0 to 1.0.1
- No breaking changes
- License change from MIT to dual-license (AGPL-3.0 OR Commercial)
- Review licensing requirements for your use case
- Contact alban.q.maxhuni@gmail.com for commercial licensing if needed

---

## Support

- **Open Source Support**: GitHub Issues
- **Commercial Support**: alban.q.maxhuni@gmail.com
- **Documentation**: README.md and docs/
- **Examples**: examples/ directory
