# Commercial License for AI Prishtina Milvus Client

## Overview

This document outlines the commercial licensing terms for the AI Prishtina Milvus Client library. If you wish to use this software in commercial applications, proprietary software, or cannot comply with the AGPL-3.0 license terms, you must obtain a commercial license.

## When Do You Need a Commercial License?

You need a commercial license if:

- ✅ You want to use the library in a **proprietary/closed-source application**
- ✅ You're developing **commercial products or services**
- ✅ You're building **SaaS applications** that use this library
- ✅ You cannot comply with **AGPL-3.0 copyleft requirements**
- ✅ You need **enterprise-grade support and SLA**
- ✅ You want **custom feature development**
- ✅ You're using it in **enterprise deployments**

## Commercial License Benefits

### 🚀 **Usage Rights**
- Use in proprietary/commercial applications
- No requirement to open-source your application
- No copyleft obligations
- Distribute without source code disclosure
- Modify and customize without restrictions

### 🛠️ **Support & Services**
- **Priority Support**: Direct access to the development team
- **Enterprise SLA**: Guaranteed response times and resolution
- **Custom Development**: Tailored features for your specific needs
- **Integration Assistance**: Help with implementation and deployment
- **Performance Optimization**: Tuning for your specific use case

### 📈 **Enterprise Features**
- **Advanced Security**: Enhanced encryption and access controls
- **Scalability Optimizations**: Performance tuning for large deployments
- **Custom Integrations**: Integration with your existing systems
- **Monitoring & Analytics**: Advanced metrics and reporting
- **Backup & Recovery**: Enterprise-grade data protection

## License Tiers

### 🥉 **Startup License**
**Perfect for startups and small businesses**

- **Price**: $2,999/year
- **Usage**: Up to 10 developers
- **Support**: Email support (48h response)
- **Features**: Standard commercial rights
- **Deployment**: Up to 3 production environments

### 🥈 **Professional License**
**Ideal for growing companies**

- **Price**: $9,999/year
- **Usage**: Up to 50 developers
- **Support**: Priority email + phone support (24h response)
- **Features**: All standard features + custom integrations
- **Deployment**: Unlimited production environments
- **Includes**: 40 hours of consulting services

### 🥇 **Enterprise License**
**For large organizations and mission-critical applications**

- **Price**: Custom pricing (starting at $25,000/year)
- **Usage**: Unlimited developers
- **Support**: Dedicated support team (4h response, 24/7 critical)
- **Features**: All features + custom development
- **Deployment**: Unlimited environments + on-premise deployment
- **Includes**: Dedicated customer success manager
- **SLA**: 99.9% uptime guarantee

## Licensing Process

### 1. **Contact Us**
Reach out to discuss your requirements:
- **Email**: alban.q.maxhuni@gmail.com
- **Subject**: "AI Prishtina Milvus Client - Commercial License"
- **Website**: https://albanmaxhuni.com

### 2. **Requirements Assessment**
We'll work with you to understand:
- Your use case and requirements
- Number of developers and deployments
- Support and service needs
- Timeline and budget considerations

### 3. **Custom Proposal**
You'll receive:
- Detailed licensing proposal
- Pricing based on your specific needs
- Service level agreements
- Implementation timeline

### 4. **License Agreement**
Upon acceptance:
- Formal license agreement execution
- License key and documentation delivery
- Support team introduction
- Implementation kickoff

## Frequently Asked Questions

### **Q: Can I try before buying?**
A: Yes! We offer a 30-day evaluation license for commercial assessment.

### **Q: What if I'm already using the AGPL version?**
A: You can migrate to a commercial license at any time. We'll help with the transition.

### **Q: Do you offer volume discounts?**
A: Yes, significant discounts are available for large deployments and multi-year agreements.

### **Q: Can I get a perpetual license?**
A: Yes, perpetual licenses are available with an upfront payment and optional maintenance.

### **Q: What about source code access?**
A: Enterprise customers can receive source code access under specific terms.

### **Q: Do you provide training?**
A: Yes, training and onboarding services are included with Professional and Enterprise licenses.

## Technical Requirements

### **Minimum Requirements**
- Python 3.9 or higher
- Milvus 2.3.0 or higher
- 4GB RAM minimum
- Network connectivity to Milvus instance

### **Recommended for Production**
- Python 3.11 or higher
- Milvus 2.3.3 or higher
- 16GB RAM or more
- High-speed network connection
- Load balancer for high availability

## Support Channels

### **Commercial License Holders**
- **Priority Email**: commercial-support@albanmaxhuni.com
- **Phone Support**: Available for Professional and Enterprise tiers
- **Slack Channel**: Private support channel
- **Video Calls**: Scheduled support sessions

### **Documentation & Resources**
- **Commercial Documentation**: Extended documentation with enterprise features
- **Best Practices Guide**: Production deployment guidelines
- **API Reference**: Complete commercial API documentation
- **Sample Applications**: Enterprise-ready example implementations

## Legal Terms

### **Intellectual Property**
- You retain ownership of your applications
- We retain ownership of the library
- Commercial license grants specific usage rights
- No transfer of intellectual property

### **Warranty & Liability**
- Commercial licenses include limited warranty
- Professional support and bug fixes
- Liability limitations as specified in license agreement
- Indemnification provisions for Enterprise customers

### **Compliance**
- GDPR compliance assistance
- SOC 2 compliance documentation
- Security audit support
- Regulatory compliance guidance

## Contact Information

**For Commercial Licensing:**
- **Primary Contact**: Alban Maxhuni, PhD
- **Email**: alban.q.maxhuni@gmail.com
- **Alternative**: info@albanmaxhuni.com
- **Website**: https://albanmaxhuni.com
- **LinkedIn**: [Alban Maxhuni](https://linkedin.com/in/albanmaxhuni)

**Business Hours:**
- **Monday - Friday**: 9:00 AM - 6:00 PM CET
- **Emergency Support**: Available for Enterprise customers

---

*This document is subject to change. Please contact us for the most current licensing terms and pricing.*
